@@ -7,6 +7,10 @@ try:
 except ImportError:
     QSvgWidget = None
 
+try :
+    from stdcomQtPath import *
+except :
+    stdcom = None
 
 from stdcomQtPjanice import *
 
